@@ -1,3 +1,3 @@
 from woflo.runners.base import BaseTaskRun
-from woflo.runners.multiprocess import MultiprocessTaskRun
+from woflo.runners.multiprocess import ForkProcess, MultiprocessTaskRun, SpawnProcess
 from woflo.runners.sequential import SequentialTaskRun
